![Python application](https://github.com/multicloud-ops/operator-csv-libs/workflows/Python%20application/badge.svg) [![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=multicloud-ops_operator-csv-libs&metric=alert_status)](https://sonarcloud.io/dashboard?id=multicloud-ops_operator-csv-libs)
# Operator CSV libs

## Usage

Place `operator-csv-libs` in your requirements.txt file or run `pip install operator-csv-libs`. 
  
Then import the library into your scrips using some form of an import statement:
```
from operator_csv_libs.csv import ClusterServiceVersion
import operator_csv_libs.package as package
```

## Documentation

The documentation for our `operator-csv-libs` library can be viewed at https://multicloud-ops.github.io/operator-csv-libs/index.html
